## Mirai Framework for Python

### 这是什么?
以 OICQ(QQ) 协议驱动的高性能机器人开发框架 [Mirai](https://github.com/mamoe/mirai) 的 Python 接口, 通过其提供的 `HTTP API` 与无头客户端(`Mirai`)交互.

### 开始使用
#### 从 Pypi 安装
``` bash
pip install kuriyama
```

#### 开始开发

由于 `python-mirai` 依赖于 `mirai` 提供的 `mirai-http-api` 插件, 所以你需要先运行一个 `mirai-core` 或是 `mirai-console` 实例以支撑你的应用运行.

现有的文档地址: https://mirai-py.originpages.com/

### 加入开发
`python-mirai` 项目欢迎一切形式上的贡献(包括但不限于 `Issues`, `Pull Requests`, `Good Idea` 等)  
我们希望能有更多优秀的开发者加入到对项目的贡献上来  

你的 `Star` 是对我们最大的支持和鼓励.  
若你在使用的过程中遇到了问题, 欢迎[提出聪明的问题](https://github.com/ryanhanwu/How-To-Ask-Questions-The-Smart-Way/blob/master/README-zh_CN.md), 我们希望有人能让这个项目变得更好.  

### 鸣谢
感谢 [`mamoe`](https://github.com/mamoe) 给我们带来 [`mirai`](https://github.com/mamoe/mirai) 这么一个如此精彩的项目.  

### 许可证
我们使用 [`GNU AGPLv3`](https://choosealicense.com/licenses/agpl-3.0/) 作为本项目的开源许可证, 而由于原项目 [`mirai`](https://github.com/mamoe/mirai) 同样使用了 `GNU AGPLv3` 作为开源许可证, 因此你在使用时需要遵守相应的规则.  